@@ -2,6 +2,7 @@
 Module for doing stuff with letters.
 """
 import random
+import requests
 
 def range(start = 1, stop = 1, step = 1):
     """Find a range from one letter to another.
@@ -161,3 +162,60 @@ def randomize(word):
     letters = list(word)
     return "".join(random.sample(letters,len(letters)))
 
+
+def derandomize(Word):
+    """
+    Show all posible words that word can be.
+    Args:
+        Word: the word to be derandomized
+    Results:
+        All valid words with the same letters
+    """
+    Word = list(Word)
+    words = requests.get("https://raw.githubusercontent.com/hostedposted/letter-tools/master/words.json").json()
+    arr = []
+    for word in words: 
+        flag = 1
+        chars = []
+        charsd = {}
+        for i in word: 
+            charsd[i] = charsd.get(i, 0) + 1
+            chars.append(i)
+        count = -1
+        for key in chars:
+            count += 1
+            if flag == 0:
+                break
+            if key not in Word: 
+                flag = 0
+            else: 
+                if Word.count(key) != charsd[key]: 
+                    flag = 0
+            if "?" in Word:
+                word_indice = [i for i, x in enumerate(Word) if x == '?']
+                if count in word_indice:
+                    flag = 1
+        if len(word) != len(Word):
+            flag = 0
+        if flag == 1:
+            arr.append(word)
+    return arr
+
+def custom_score(word, opt):
+    """
+    Make your custom word score. Just put in a dictionary each letter being assigned a score.
+    Args:
+        word: the word to get the score of
+        opt: the options to use.
+    Retuns:
+        The word in the score opt gave.
+    Raises:
+        Exception: if opt is not a dict
+    """
+    if isinstance(opt, dict) == False:
+        raise Exception("options are not a dict.")
+    score = 0
+    for i in list(word):
+        score += opt[i]
+        
+    return score
\ No newline at end of file
